==> aws-cdk-scala-athena_3-0.1.4-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"athena","t":"athena","d":"","k":"static"},
{"l":"io/burkard/cdk/services/athena.html","n":"io.burkard.cdk.services.athena","t":"package io.burkard.cdk.services.athena","d":"io/burkard/cdk/services/athena","k":"package"},
{"l":"io/burkard/cdk/services/athena/CfnDataCatalog$.html","n":"CfnDataCatalog","t":"object CfnDataCatalog","d":"io/burkard/cdk/services/athena/CfnDataCatalog$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnDataCatalog$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], `type`: Option[String], parameters: Option[Map[String, String]], description: Option[String], tags: Option[List[_ <: CfnTag]])(implicit stackCtx: Stack): CfnDataCatalog","d":"io/burkard/cdk/services/athena/CfnDataCatalog$","k":"def"},
{"l":"io/burkard/cdk/services/athena/CfnDataCatalogProps$.html","n":"CfnDataCatalogProps","t":"object CfnDataCatalogProps","d":"io/burkard/cdk/services/athena/CfnDataCatalogProps$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnDataCatalogProps$.html","n":"apply","t":"def apply(name: Option[String], `type`: Option[String], parameters: Option[Map[String, String]], description: Option[String], tags: Option[List[_ <: CfnTag]]): CfnDataCatalogProps","d":"io/burkard/cdk/services/athena/CfnDataCatalogProps$","k":"def"},
{"l":"io/burkard/cdk/services/athena/CfnNamedQuery$.html","n":"CfnNamedQuery","t":"object CfnNamedQuery","d":"io/burkard/cdk/services/athena/CfnNamedQuery$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnNamedQuery$.html","n":"apply","t":"def apply(internalResourceId: String, workGroup: Option[String], database: Option[String], name: Option[String], description: Option[String], queryString: Option[String])(implicit stackCtx: Stack): CfnNamedQuery","d":"io/burkard/cdk/services/athena/CfnNamedQuery$","k":"def"},
{"l":"io/burkard/cdk/services/athena/CfnNamedQueryProps$.html","n":"CfnNamedQueryProps","t":"object CfnNamedQueryProps","d":"io/burkard/cdk/services/athena/CfnNamedQueryProps$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnNamedQueryProps$.html","n":"apply","t":"def apply(workGroup: Option[String], database: Option[String], name: Option[String], description: Option[String], queryString: Option[String]): CfnNamedQueryProps","d":"io/burkard/cdk/services/athena/CfnNamedQueryProps$","k":"def"},
{"l":"io/burkard/cdk/services/athena/CfnPreparedStatement$.html","n":"CfnPreparedStatement","t":"object CfnPreparedStatement","d":"io/burkard/cdk/services/athena/CfnPreparedStatement$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnPreparedStatement$.html","n":"apply","t":"def apply(internalResourceId: String, workGroup: Option[String], description: Option[String], queryStatement: Option[String], statementName: Option[String])(implicit stackCtx: Stack): CfnPreparedStatement","d":"io/burkard/cdk/services/athena/CfnPreparedStatement$","k":"def"},
{"l":"io/burkard/cdk/services/athena/CfnPreparedStatementProps$.html","n":"CfnPreparedStatementProps","t":"object CfnPreparedStatementProps","d":"io/burkard/cdk/services/athena/CfnPreparedStatementProps$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnPreparedStatementProps$.html","n":"apply","t":"def apply(workGroup: Option[String], description: Option[String], queryStatement: Option[String], statementName: Option[String]): CfnPreparedStatementProps","d":"io/burkard/cdk/services/athena/CfnPreparedStatementProps$","k":"def"},
{"l":"io/burkard/cdk/services/athena/CfnWorkGroup$.html","n":"CfnWorkGroup","t":"object CfnWorkGroup","d":"io/burkard/cdk/services/athena/CfnWorkGroup$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnWorkGroup$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], state: Option[String], workGroupConfiguration: Option[WorkGroupConfigurationProperty], workGroupConfigurationUpdates: Option[WorkGroupConfigurationUpdatesProperty], recursiveDeleteOption: Option[Boolean], description: Option[String], tags: Option[List[_ <: CfnTag]])(implicit stackCtx: Stack): CfnWorkGroup","d":"io/burkard/cdk/services/athena/CfnWorkGroup$","k":"def"},
{"l":"io/burkard/cdk/services/athena/CfnWorkGroupProps$.html","n":"CfnWorkGroupProps","t":"object CfnWorkGroupProps","d":"io/burkard/cdk/services/athena/CfnWorkGroupProps$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnWorkGroupProps$.html","n":"apply","t":"def apply(name: Option[String], state: Option[String], workGroupConfiguration: Option[WorkGroupConfigurationProperty], workGroupConfigurationUpdates: Option[WorkGroupConfigurationUpdatesProperty], recursiveDeleteOption: Option[Boolean], description: Option[String], tags: Option[List[_ <: CfnTag]]): CfnWorkGroupProps","d":"io/burkard/cdk/services/athena/CfnWorkGroupProps$","k":"def"},
{"l":"io/burkard/cdk/services/athena/EncryptionConfigurationProperty$.html","n":"EncryptionConfigurationProperty","t":"object EncryptionConfigurationProperty","d":"io/burkard/cdk/services/athena/EncryptionConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/athena/EncryptionConfigurationProperty$.html","n":"apply","t":"def apply(kmsKey: Option[String], encryptionOption: Option[String]): EncryptionConfigurationProperty","d":"io/burkard/cdk/services/athena/EncryptionConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/athena/EngineVersionProperty$.html","n":"EngineVersionProperty","t":"object EngineVersionProperty","d":"io/burkard/cdk/services/athena/EngineVersionProperty$","k":"object"},
{"l":"io/burkard/cdk/services/athena/EngineVersionProperty$.html","n":"apply","t":"def apply(selectedEngineVersion: Option[String], effectiveEngineVersion: Option[String]): EngineVersionProperty","d":"io/burkard/cdk/services/athena/EngineVersionProperty$","k":"def"},
{"l":"io/burkard/cdk/services/athena/ResultConfigurationProperty$.html","n":"ResultConfigurationProperty","t":"object ResultConfigurationProperty","d":"io/burkard/cdk/services/athena/ResultConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/athena/ResultConfigurationProperty$.html","n":"apply","t":"def apply(encryptionConfiguration: Option[EncryptionConfigurationProperty], outputLocation: Option[String]): ResultConfigurationProperty","d":"io/burkard/cdk/services/athena/ResultConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/athena/ResultConfigurationUpdatesProperty$.html","n":"ResultConfigurationUpdatesProperty","t":"object ResultConfigurationUpdatesProperty","d":"io/burkard/cdk/services/athena/ResultConfigurationUpdatesProperty$","k":"object"},
{"l":"io/burkard/cdk/services/athena/ResultConfigurationUpdatesProperty$.html","n":"apply","t":"def apply(encryptionConfiguration: Option[EncryptionConfigurationProperty], outputLocation: Option[String], removeOutputLocation: Option[Boolean], removeEncryptionConfiguration: Option[Boolean]): ResultConfigurationUpdatesProperty","d":"io/burkard/cdk/services/athena/ResultConfigurationUpdatesProperty$","k":"def"},
{"l":"io/burkard/cdk/services/athena/WorkGroupConfigurationProperty$.html","n":"WorkGroupConfigurationProperty","t":"object WorkGroupConfigurationProperty","d":"io/burkard/cdk/services/athena/WorkGroupConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/athena/WorkGroupConfigurationProperty$.html","n":"apply","t":"def apply(enforceWorkGroupConfiguration: Option[Boolean], requesterPaysEnabled: Option[Boolean], bytesScannedCutoffPerQuery: Option[Number], engineVersion: Option[EngineVersionProperty], publishCloudWatchMetricsEnabled: Option[Boolean], resultConfiguration: Option[ResultConfigurationProperty]): WorkGroupConfigurationProperty","d":"io/burkard/cdk/services/athena/WorkGroupConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/athena/WorkGroupConfigurationUpdatesProperty$.html","n":"WorkGroupConfigurationUpdatesProperty","t":"object WorkGroupConfigurationUpdatesProperty","d":"io/burkard/cdk/services/athena/WorkGroupConfigurationUpdatesProperty$","k":"object"},
{"l":"io/burkard/cdk/services/athena/WorkGroupConfigurationUpdatesProperty$.html","n":"apply","t":"def apply(enforceWorkGroupConfiguration: Option[Boolean], resultConfigurationUpdates: Option[ResultConfigurationUpdatesProperty], removeBytesScannedCutoffPerQuery: Option[Boolean], publishCloudWatchMetricsEnabled: Option[Boolean], requesterPaysEnabled: Option[Boolean], bytesScannedCutoffPerQuery: Option[Number], engineVersion: Option[EngineVersionProperty]): WorkGroupConfigurationUpdatesProperty","d":"io/burkard/cdk/services/athena/WorkGroupConfigurationUpdatesProperty$","k":"def"},
{"l":"docs/index.html","n":"athena","t":"athena","d":"","k":"static"}];

==> aws-cdk-scala-athena_3-0.1.7-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"athena","t":"athena","d":"","k":"static"},
{"l":"io/burkard/cdk/services/athena.html","n":"io.burkard.cdk.services.athena","t":"package io.burkard.cdk.services.athena","d":"io/burkard/cdk/services/athena","k":"package"},
{"l":"io/burkard/cdk/services/athena/CfnDataCatalog$.html","n":"CfnDataCatalog","t":"object CfnDataCatalog","d":"io/burkard/cdk/services/athena/CfnDataCatalog$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnDataCatalog$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, `type`: String, parameters: Option[Map[String, String]], description: Option[String], tags: Option[List[_ <: CfnTag]])(implicit stackCtx: Stack): CfnDataCatalog","d":"io/burkard/cdk/services/athena/CfnDataCatalog$","k":"def"},
{"l":"io/burkard/cdk/services/athena/CfnDataCatalogProps$.html","n":"CfnDataCatalogProps","t":"object CfnDataCatalogProps","d":"io/burkard/cdk/services/athena/CfnDataCatalogProps$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnDataCatalogProps$.html","n":"apply","t":"def apply(name: String, `type`: String, parameters: Option[Map[String, String]], description: Option[String], tags: Option[List[_ <: CfnTag]]): CfnDataCatalogProps","d":"io/burkard/cdk/services/athena/CfnDataCatalogProps$","k":"def"},
{"l":"io/burkard/cdk/services/athena/CfnNamedQuery$.html","n":"CfnNamedQuery","t":"object CfnNamedQuery","d":"io/burkard/cdk/services/athena/CfnNamedQuery$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnNamedQuery$.html","n":"apply","t":"def apply(internalResourceId: String, database: String, queryString: String, workGroup: Option[String], name: Option[String], description: Option[String])(implicit stackCtx: Stack): CfnNamedQuery","d":"io/burkard/cdk/services/athena/CfnNamedQuery$","k":"def"},
{"l":"io/burkard/cdk/services/athena/CfnNamedQueryProps$.html","n":"CfnNamedQueryProps","t":"object CfnNamedQueryProps","d":"io/burkard/cdk/services/athena/CfnNamedQueryProps$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnNamedQueryProps$.html","n":"apply","t":"def apply(database: String, queryString: String, workGroup: Option[String], name: Option[String], description: Option[String]): CfnNamedQueryProps","d":"io/burkard/cdk/services/athena/CfnNamedQueryProps$","k":"def"},
{"l":"io/burkard/cdk/services/athena/CfnPreparedStatement$.html","n":"CfnPreparedStatement","t":"object CfnPreparedStatement","d":"io/burkard/cdk/services/athena/CfnPreparedStatement$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnPreparedStatement$.html","n":"apply","t":"def apply(internalResourceId: String, workGroup: String, queryStatement: String, statementName: String, description: Option[String])(implicit stackCtx: Stack): CfnPreparedStatement","d":"io/burkard/cdk/services/athena/CfnPreparedStatement$","k":"def"},
{"l":"io/burkard/cdk/services/athena/CfnPreparedStatementProps$.html","n":"CfnPreparedStatementProps","t":"object CfnPreparedStatementProps","d":"io/burkard/cdk/services/athena/CfnPreparedStatementProps$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnPreparedStatementProps$.html","n":"apply","t":"def apply(workGroup: String, queryStatement: String, statementName: String, description: Option[String]): CfnPreparedStatementProps","d":"io/burkard/cdk/services/athena/CfnPreparedStatementProps$","k":"def"},
{"l":"io/burkard/cdk/services/athena/CfnWorkGroup$.html","n":"CfnWorkGroup","t":"object CfnWorkGroup","d":"io/burkard/cdk/services/athena/CfnWorkGroup$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnWorkGroup$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, state: Option[String], workGroupConfiguration: Option[WorkGroupConfigurationProperty], workGroupConfigurationUpdates: Option[WorkGroupConfigurationUpdatesProperty], recursiveDeleteOption: Option[Boolean], description: Option[String], tags: Option[List[_ <: CfnTag]])(implicit stackCtx: Stack): CfnWorkGroup","d":"io/burkard/cdk/services/athena/CfnWorkGroup$","k":"def"},
{"l":"io/burkard/cdk/services/athena/CfnWorkGroupProps$.html","n":"CfnWorkGroupProps","t":"object CfnWorkGroupProps","d":"io/burkard/cdk/services/athena/CfnWorkGroupProps$","k":"object"},
{"l":"io/burkard/cdk/services/athena/CfnWorkGroupProps$.html","n":"apply","t":"def apply(name: String, state: Option[String], workGroupConfiguration: Option[WorkGroupConfigurationProperty], workGroupConfigurationUpdates: Option[WorkGroupConfigurationUpdatesProperty], recursiveDeleteOption: Option[Boolean], description: Option[String], tags: Option[List[_ <: CfnTag]]): CfnWorkGroupProps","d":"io/burkard/cdk/services/athena/CfnWorkGroupProps$","k":"def"},
{"l":"io/burkard/cdk/services/athena/EncryptionConfigurationProperty$.html","n":"EncryptionConfigurationProperty","t":"object EncryptionConfigurationProperty","d":"io/burkard/cdk/services/athena/EncryptionConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/athena/EncryptionConfigurationProperty$.html","n":"apply","t":"def apply(encryptionOption: String, kmsKey: Option[String]): EncryptionConfigurationProperty","d":"io/burkard/cdk/services/athena/EncryptionConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/athena/EngineVersionProperty$.html","n":"EngineVersionProperty","t":"object EngineVersionProperty","d":"io/burkard/cdk/services/athena/EngineVersionProperty$","k":"object"},
{"l":"io/burkard/cdk/services/athena/EngineVersionProperty$.html","n":"apply","t":"def apply(selectedEngineVersion: Option[String], effectiveEngineVersion: Option[String]): EngineVersionProperty","d":"io/burkard/cdk/services/athena/EngineVersionProperty$","k":"def"},
{"l":"io/burkard/cdk/services/athena/ResultConfigurationProperty$.html","n":"ResultConfigurationProperty","t":"object ResultConfigurationProperty","d":"io/burkard/cdk/services/athena/ResultConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/athena/ResultConfigurationProperty$.html","n":"apply","t":"def apply(encryptionConfiguration: Option[EncryptionConfigurationProperty], outputLocation: Option[String]): ResultConfigurationProperty","d":"io/burkard/cdk/services/athena/ResultConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/athena/ResultConfigurationUpdatesProperty$.html","n":"ResultConfigurationUpdatesProperty","t":"object ResultConfigurationUpdatesProperty","d":"io/burkard/cdk/services/athena/ResultConfigurationUpdatesProperty$","k":"object"},
{"l":"io/burkard/cdk/services/athena/ResultConfigurationUpdatesProperty$.html","n":"apply","t":"def apply(encryptionConfiguration: Option[EncryptionConfigurationProperty], outputLocation: Option[String], removeOutputLocation: Option[Boolean], removeEncryptionConfiguration: Option[Boolean]): ResultConfigurationUpdatesProperty","d":"io/burkard/cdk/services/athena/ResultConfigurationUpdatesProperty$","k":"def"},
{"l":"io/burkard/cdk/services/athena/WorkGroupConfigurationProperty$.html","n":"WorkGroupConfigurationProperty","t":"object WorkGroupConfigurationProperty","d":"io/burkard/cdk/services/athena/WorkGroupConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/athena/WorkGroupConfigurationProperty$.html","n":"apply","t":"def apply(enforceWorkGroupConfiguration: Option[Boolean], requesterPaysEnabled: Option[Boolean], bytesScannedCutoffPerQuery: Option[Number], engineVersion: Option[EngineVersionProperty], publishCloudWatchMetricsEnabled: Option[Boolean], resultConfiguration: Option[ResultConfigurationProperty]): WorkGroupConfigurationProperty","d":"io/burkard/cdk/services/athena/WorkGroupConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/athena/WorkGroupConfigurationUpdatesProperty$.html","n":"WorkGroupConfigurationUpdatesProperty","t":"object WorkGroupConfigurationUpdatesProperty","d":"io/burkard/cdk/services/athena/WorkGroupConfigurationUpdatesProperty$","k":"object"},
{"l":"io/burkard/cdk/services/athena/WorkGroupConfigurationUpdatesProperty$.html","n":"apply","t":"def apply(enforceWorkGroupConfiguration: Option[Boolean], resultConfigurationUpdates: Option[ResultConfigurationUpdatesProperty], removeBytesScannedCutoffPerQuery: Option[Boolean], publishCloudWatchMetricsEnabled: Option[Boolean], requesterPaysEnabled: Option[Boolean], bytesScannedCutoffPerQuery: Option[Number], engineVersion: Option[EngineVersionProperty]): WorkGroupConfigurationUpdatesProperty","d":"io/burkard/cdk/services/athena/WorkGroupConfigurationUpdatesProperty$","k":"def"},
{"l":"docs/index.html","n":"athena","t":"athena","d":"","k":"static"}];
